# Copyright (C) 2020-2025 Soleta Networks <info@soleta.eu>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.

from src.kiosk.config import *
from PyQt6.QtGui import QPixmap, QPainter, QColor, QIcon
from PyQt6.QtCore import Qt
import os

BUTTON_HEIGHT = 55
BUTTON_WIDTH = 390
BUTTON_ICON_SIZE = 25
POWER_ICON_SIZE = 50

def colorize_pixmap(pixmap, color):
    # Create a new pixmap with the same size
    colorized_pixmap = QPixmap(pixmap.size())
    colorized_pixmap.fill(Qt.GlobalColor.transparent)

    # Paint the original pixmap and apply the color overlay
    painter = QPainter(colorized_pixmap)
    painter.drawPixmap(0, 0, pixmap)

    painter.setCompositionMode(QPainter.CompositionMode.CompositionMode_SourceIn)
    painter.fillRect(colorized_pixmap.rect(), color)
    painter.end()

    return colorized_pixmap

def get_icon(icon_name):
    icon_pixmap = get_image(icon_name)
    return QIcon(colorize_pixmap(icon_pixmap, get_main_color_theme()))

def get_image(image_name):
    base_dir = base_dir = os.path.abspath(
        os.path.dirname(__file__)
    )
    img_path = os.path.join(base_dir, 'img', image_name)
    pixmap = QPixmap(img_path)
    if pixmap.isNull():
        print(f'Could not load {img_path}')
    return pixmap
